@@ -131,7 +131,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self._ispainted = True
 
     def paintNow(self):
-        """ Enforce a repaint and keep calling processEvents until
+        """Enforce a repaint and keep calling processEvents until
         we are repainted.
         """
         self._ispainted = False
@@ -210,8 +210,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 pyzo.toolManager.loadTool(toolId)
 
     def setMainTitle(self, path=None):
-        """ Set the title of the main window, by giving a file path.
-        """
+        """Set the title of the main window, by giving a file path."""
         if not path:
             # Plain title
             title = "Interactive Editor for Python"
@@ -239,10 +238,10 @@ class MainWindow(QtWidgets.QMainWindow):
         self.setWindowTitle(title)
 
     def saveWindowState(self):
-        """ Save:
-            * which tools are loaded
-            * geometry of the top level windows
-            * layout of dockwidgets and toolbars
+        """Save:
+        * which tools are loaded
+        * geometry of the top level windows
+        * layout of dockwidgets and toolbars
         """
 
         # Save tool list
@@ -251,20 +250,12 @@ class MainWindow(QtWidgets.QMainWindow):
 
         # Store window geometry
         geometry = self.saveGeometry()
-        try:
-            geometry = bytes(geometry)  # PyQt4
-        except Exception:
-            geometry = bytes().join(geometry)  # PySide
-        geometry = base64.encodebytes(geometry).decode("ascii")
+        geometry = base64.encodebytes(geometry.data()).decode("ascii")
         pyzo.config.state.windowGeometry = geometry
 
         # Store window state
         state = self.saveState()
-        try:
-            state = bytes(state)  # PyQt4
-        except Exception:
-            state = bytes().join(state)  # PySide
-        state = base64.encodebytes(state).decode("ascii")
+        state = base64.encodebytes(state.data()).decode("ascii")
         pyzo.config.state.windowState = state
 
     def restoreGeometry(self, value=None):
@@ -298,7 +289,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 print("Could not restore window state: " + str(err))
 
     def setQtStyle(self, stylename=None):
-        """ Set the style and the palette, based on the given style name.
+        """Set the style and the palette, based on the given style name.
         If stylename is None or not given will do some initialization.
         If bool(stylename) evaluates to False will use the default style
         for this system. Returns the QStyle instance.
@@ -347,7 +338,7 @@ class MainWindow(QtWidgets.QMainWindow):
         return qstyle
 
     def closeEvent(self, event):
-        """ Override close event handler. """
+        """Override close event handler."""
 
         # Are we restaring?
         restarting = time.time() - self._closeflag < 1.0
@@ -371,13 +362,15 @@ class MainWindow(QtWidgets.QMainWindow):
 
         # Proceed with closing shells
         pyzo.localKernelManager.terminateAll()
+
         for shell in pyzo.shells:
             shell._context.close()
 
-        # Close tools
+        # The tools need to be explicitly closed to allow them to clean up
         for toolname in pyzo.toolManager.getLoadedTools():
             tool = pyzo.toolManager.getTool(toolname)
-            tool.close()
+            if hasattr(tool, "cleanUp"):
+                tool.cleanUp()
 
         # Stop all threads (this should really only be daemon threads)
         import threading
@@ -407,7 +400,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 os._exit(0)
 
     def restart(self):
-        """ Restart Pyzo. """
+        """Restart Pyzo."""
 
         self._closeflag = time.time()
 
@@ -460,7 +453,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
 
 def loadAppIcons():
-    """ loadAppIcons()
+    """loadAppIcons()
     Load the application iconsr.
     """
     # Get directory containing the icons
@@ -495,7 +488,7 @@ def loadAppIcons():
 
 
 def loadIcons():
-    """ loadIcons()
+    """loadIcons()
     Load all icons in the icon dir.
     """
     # Get directory containing the icons
@@ -522,7 +515,7 @@ def loadIcons():
 
 
 def loadFonts():
-    """ loadFonts()
+    """loadFonts()
     Load all fonts that come with Pyzo.
     """
     import pyzo.codeeditor  # we need pyzo and codeeditor namespace here
@@ -549,8 +542,7 @@ def loadFonts():
 
 
 class _CallbackEventHandler(QtCore.QObject):
-    """ Helper class to provide the callLater function.
-    """
+    """Helper class to provide the callLater function."""
 
     def __init__(self):
         QtCore.QObject.__init__(self)
@@ -573,7 +565,7 @@ class _CallbackEventHandler(QtCore.QObject):
 
 
 def callLater(callback, *args):
-    """ callLater(callback, *args)
+    """callLater(callback, *args)
     Post a callback to be called in the main thread.
     """
     _callbackEventHandler.postEventWithCallback(callback, *args)
