@@ -12,10 +12,10 @@ from .utils import cleanpath, isdir
 
 
 class Browser(QtWidgets.QWidget):
-    """ A browser consists of an address bar, and tree view, and other
+    """A browser consists of an address bar, and tree view, and other
     widets to help browse the file system. The browser object is responsible
     for tying the different browser-components together.
-    
+
     It is also provides the API for dealing with starred dirs.
     """
 
@@ -98,9 +98,7 @@ class Browser(QtWidgets.QWidget):
         subLayout.addWidget(self._searchFilter, 5)
         layout.addLayout(subLayout)
 
-    def closeEvent(self, event):
-        # print('Closing browser, stopping file system proxy')
-        super().closeEvent(event)
+    def cleanUp(self):
         self._fsProxy.stop()
 
     def nameFilter(self):
@@ -117,18 +115,16 @@ class Browser(QtWidgets.QWidget):
 
     @property
     def expandedDirs(self):
-        """ The list of the expanded directories.
-        """
+        """The list of the expanded directories."""
         return self.parent().config.expandedDirs
 
     @property
     def starredDirs(self):
-        """ A list of the starred directories.
-        """
+        """A list of the starred directories."""
         return [d.path for d in self.parent().config.starredDirs]
 
     def dictForStarredDir(self, path):
-        """ Return the dict of the starred dir corresponding to
+        """Return the dict of the starred dir corresponding to
         the given path, or None if no starred dir was found.
         """
         if not path:
@@ -140,8 +136,7 @@ class Browser(QtWidgets.QWidget):
             return None
 
     def addStarredDir(self, path):
-        """ Add the given path to the starred directories.
-        """
+        """Add the given path to the starred directories."""
         # Create new dict
         newProject = ssdf.new()
         newProject.path = op.normcase(path)  # Normalize case!
@@ -153,7 +148,7 @@ class Browser(QtWidgets.QWidget):
         self._projects.updateProjectList()
 
     def removeStarredDir(self, path):
-        """ Remove the given path from the starred directories.
+        """Remove the given path from the starred directories.
         The path must exactlty match.
         """
         # Remove
@@ -180,14 +175,12 @@ class Browser(QtWidgets.QWidget):
             self._tree.addTopLevelItem(item)
 
     def currentProject(self):
-        """ Return the ssdf dict for the current project, or None.
-        """
+        """Return the ssdf dict for the current project, or None."""
         return self._projects.currentDict()
 
 
 class LineEditWithToolButtons(QtWidgets.QLineEdit):
-    """ Line edit to which tool buttons (with icons) can be attached.
-    """
+    """Line edit to which tool buttons (with icons) can be attached."""
 
     def __init__(self, parent):
         QtWidgets.QLineEdit.__init__(self, parent)
@@ -252,7 +245,10 @@ class LineEditWithToolButtons(QtWidgets.QLineEdit):
             if but.isVisible():
                 sz = but.sizeHint()
                 height = max(height, sz.height())
-                but.move(1 + paddingLeft, (rect.bottom() + 1 - sz.height()) / 2)
+                but.move(
+                    int(1 + paddingLeft),
+                    int(rect.bottom() + 1 - sz.height()) // 2,
+                )
                 paddingLeft += sz.width() + 1
         #
         for but in self._rightButtons:
@@ -261,8 +257,8 @@ class LineEditWithToolButtons(QtWidgets.QLineEdit):
                 paddingRight += sz.width() + 1
                 height = max(height, sz.height())
                 but.move(
-                    rect.right() - 1 - paddingRight,
-                    (rect.bottom() + 1 - sz.height()) / 2,
+                    int(rect.right() - 1 - paddingRight),
+                    int(rect.bottom() + 1 - sz.height()) // 2,
                 )
 
         # Set padding
@@ -281,8 +277,7 @@ class LineEditWithToolButtons(QtWidgets.QLineEdit):
 
 
 class PathInput(LineEditWithToolButtons):
-    """ Line edit for selecting a path.
-    """
+    """Line edit for selecting a path."""
 
     dirChanged = QtCore.Signal(
         str
@@ -316,8 +311,7 @@ class PathInput(LineEditWithToolButtons):
         # self.cursorPositionChanged.connect(self.onTextEdited)
 
     def setPath(self, path):
-        """ Set the path to display. Does nothing if this widget has focus.
-        """
+        """Set the path to display. Does nothing if this widget has focus."""
         if not self.hasFocus():
             self.setText(path)
             self.checkValid()  # Reset style if it was invalid first
@@ -355,7 +349,7 @@ class PathInput(LineEditWithToolButtons):
             self.dirChanged.emit(cleanpath(text))
 
     def focusOutEvent(self, event=None):
-        """ focusOutEvent(event)
+        """focusOutEvent(event)
         On focusing out, make sure that the set path is correct.
         """
         if event is not None:
@@ -410,8 +404,7 @@ class Projects(QtWidgets.QWidget):
         layout.setContentsMargins(0, 0, 0, 0)
 
     def currentDict(self):
-        """ Return the current project-dict, or None.
-        """
+        """Return the current project-dict, or None."""
         path = self._combo.itemData(self._combo.currentIndex())
         return self.parent().dictForStarredDir(path)
 
@@ -538,8 +531,7 @@ class Projects(QtWidgets.QWidget):
 
 
 class NameFilter(LineEditWithToolButtons):
-    """ Combobox to filter by name.
-    """
+    """Combobox to filter by name."""
 
     filterChanged = QtCore.Signal()
 
@@ -575,8 +567,7 @@ class NameFilter(LineEditWithToolButtons):
         self.setText(config.nameFilter)
 
     def setText(self, value, test=False):
-        """ To initialize the name filter.
-        """
+        """To initialize the name filter."""
         QtWidgets.QLineEdit.setText(self, value)
         if test:
             self.checkFilterValue()
@@ -594,8 +585,7 @@ class NameFilter(LineEditWithToolButtons):
 
 
 class SearchFilter(LineEditWithToolButtons):
-    """ Line edit to do a search in the files.
-    """
+    """Line edit to do a search in the files."""
 
     filterChanged = QtCore.Signal()
 
@@ -623,8 +613,7 @@ class SearchFilter(LineEditWithToolButtons):
         self.returnPressed.connect(self.forceFilterChanged)
 
     def onCancelPressed(self):
-        """ Clear text or build menu.
-        """
+        """Clear text or build menu."""
         if self.text():
             QtWidgets.QLineEdit.clear(self)
             self.checkFilterValue()
